;; Generated package description from mode: lisp-data; .el  -*- fontaineno-byte-compile: t -*-
(define-package "fontaine" "3.0.1" "Set font configurations using presets" '((emacs "29.1")) :commit "34d8b04bef350b270f52dc4defc9bac3e9617bf0" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/fontaine")
